All Classes and Interfaces
Class
Description
The Class CsvRead.
The Interface EnableExcelRead.
The Class ExcelReadConfiguration.
This class is for configurations.
This class is for configurations.
The Enum ExcelExceptionType.
ExcelExceptionType is a list of type of exception message.
ExcelExceptionType is a list of type of exception message.
The Class ExcelRead.
ExcelRead is the object that represents the excel file.
It is composed by: ReportExcel - to set the excel file in byte array ListSheetRead - to set a SheetRead list where each object is a new instance MapSheet - to get result SheetRead list through class type ExcelType - to set the xls or xlsx type
ExcelRead is the object that represents the excel file.
It is composed by: ReportExcel - to set the excel file in byte array ListSheetRead - to set a SheetRead list where each object is a new instance MapSheet - to get result SheetRead list through class type ExcelType - to set the xls or xlsx type
The Interface ExcelReadColumn.
ExcelReadColumn is used to map the header column with the field in the
ExcelReadColumn is used to map the header column with the field in the
RowSheetRead classes.The Interface ExcelReaderConstant.
The Class ExcelReaderException.
ExcelReaderException is used to manage the exceptions when reading the excel.
ExcelReaderException is used to manage the exceptions when reading the excel.
The Interface ExcelReadSheet.
ExcelReadSheet is used to define the row and column start and is used in the
ExcelReadSheet is used to define the row and column start and is used in the
SheetRead classes.The Enum ExcelType.
The Class FieldCsv.
The Interface JsonSheet.
The Interface JsonExcel.
The Class MapSheetRead.
The Interface ReadCsv.
The Class ReadCsvImpl.
The Interface ReadExcel.
The Class ReadExcelImpl.
ReadExcelImpl is the class that read excel file and converts it to a SheetRead list.
ReadExcelImpl is the class that read excel file and converts it to a SheetRead list.
The Interface RowSheetRead.
RowSheetRead is used to create an object that represents the row of the sheet.
RowSheetRead is used to create an object that represents the row of the sheet.
The Class ExcelReadDeserialaizer.
The Class SheetRead.
SheetRead is the object that represents the excel sheet.
It is composed by: ListRowSheet - to get the result of the RowSheetRead list SheetName - to get the excel sheet through the name
SheetRead is the object that represents the excel sheet.
It is composed by: ListRowSheet - to get the result of the RowSheetRead list SheetName - to get the excel sheet through the name